==> jc-1.4.0.tar.gz: java/util/logging/XMLFormatter.h <==
// public class java.util.logging.XMLFormatter

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class afd6918748171c7a java_util_logging_Formatter
// @dep_class 762525b04b4e3b7f java_util_logging_XMLFormatter

// header file dependencies
// @dep_header java_util_logging_Formatter

#include "java/util/logging/Formatter.h"

#ifndef _JC_java_util_logging_XMLFormatter_H_
#define _JC_java_util_logging_XMLFormatter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_StringBuffer$object;
struct _jc_java_text_SimpleDateFormat$object;
struct _jc_java_util_logging_Handler$object;
struct _jc_java_util_logging_LogRecord$object;

// Typedefs
typedef struct _jc_java_util_logging_XMLFormatter$sub_refs	_jc_java_util_logging_XMLFormatter$sub_refs;
typedef struct _jc_java_util_logging_XMLFormatter$sub_nonrefs	_jc_java_util_logging_XMLFormatter$sub_nonrefs;
typedef struct _jc_java_util_logging_XMLFormatter$refs	_jc_java_util_logging_XMLFormatter$refs;
typedef struct _jc_java_util_logging_XMLFormatter$nonrefs	_jc_java_util_logging_XMLFormatter$nonrefs;
typedef struct _jc_java_util_logging_XMLFormatter$object	_jc_java_util_logging_XMLFormatter$object;

typedef struct _jc_java_util_logging_XMLFormatter$fields_struct	_jc_java_util_logging_XMLFormatter$fields_struct;
typedef const struct _jc_java_util_logging_XMLFormatter$vmethods	_jc_java_util_logging_XMLFormatter$vmethods;
typedef const struct _jc_java_util_logging_XMLFormatter$vtable	_jc_java_util_logging_XMLFormatter$vtable;
typedef const struct _jc_java_util_logging_XMLFormatter$vtype	_jc_java_util_logging_XMLFormatter$vtype;

// Class fields structure
struct _jc_java_util_logging_XMLFormatter$fields_struct {
	struct _jc_java_lang_String$object	*lineSep;
};
extern _jc_java_util_logging_XMLFormatter$fields_struct _jc_java_util_logging_XMLFormatter$class_fields;

// Constructors
extern void _jc_java_util_logging_XMLFormatter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_logging_XMLFormatter$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_util_logging_XMLFormatter$method$format$8b25c74979926e38(_jc_env *, struct _jc_java_util_logging_XMLFormatter$object *, struct _jc_java_util_logging_LogRecord$object *);
extern struct _jc_java_lang_String$object *_jc_java_util_logging_XMLFormatter$method$getHead$98b66758a6126109(_jc_env *, struct _jc_java_util_logging_XMLFormatter$object *, struct _jc_java_util_logging_Handler$object *);
extern struct _jc_java_lang_String$object *_jc_java_util_logging_XMLFormatter$method$getTail$ec946c1f995c0254(_jc_env *, struct _jc_java_util_logging_XMLFormatter$object *, struct _jc_java_util_logging_Handler$object *);
extern void _jc_java_util_logging_XMLFormatter$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_util_logging_XMLFormatter$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_logging_XMLFormatter$method_info$format$8b25c74979926e38;
extern _jc_method _jc_java_util_logging_XMLFormatter$method_info$getHead$98b66758a6126109;
extern _jc_method _jc_java_util_logging_XMLFormatter$method_info$getTail$ec946c1f995c0254;
extern _jc_method _jc_java_util_logging_XMLFormatter$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern void _jc_java_util_logging_XMLFormatter$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern void _jc_java_util_logging_XMLFormatter$method$appendTag$08c4a55cd695c006(_jc_env *, struct _jc_java_lang_StringBuffer$object *, jint, struct _jc_java_lang_String$object *, jlong);
extern void _jc_java_util_logging_XMLFormatter$method$appendTag$9e44c7a10e6953e8(_jc_env *, struct _jc_java_lang_StringBuffer$object *, jint, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_util_logging_XMLFormatter$vmethods {
	struct _jc_java_lang_String$object	*(*format$8b25c74979926e38)(_jc_env *, struct _jc_java_util_logging_XMLFormatter$object *, struct _jc_java_util_logging_LogRecord$object *);
	struct _jc_java_lang_String$object	*(*getHead$98b66758a6126109)(_jc_env *, struct _jc_java_util_logging_XMLFormatter$object *, struct _jc_java_util_logging_Handler$object *);
	struct _jc_java_lang_String$object	*(*getTail$ec946c1f995c0254)(_jc_env *, struct _jc_java_util_logging_XMLFormatter$object *, struct _jc_java_util_logging_Handler$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_util_logging_XMLFormatter$object *);
};

// Vtable
struct _jc_java_util_logging_XMLFormatter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_logging_Formatter$vmethods	java_util_logging_Formatter;
	_jc_java_util_logging_XMLFormatter$vmethods	java_util_logging_XMLFormatter;
};

// Vtype
struct _jc_java_util_logging_XMLFormatter$vtype {
	_jc_type			type;
	_jc_java_util_logging_XMLFormatter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_logging_XMLFormatter$sub_refs {
	struct _jc_java_text_SimpleDateFormat$object	*iso8601;
};

// Reference instance fields (object)
struct _jc_java_util_logging_XMLFormatter$refs {
    _jc_java_util_logging_XMLFormatter$sub_refs	java_util_logging_XMLFormatter;
    _jc_java_util_logging_Formatter$sub_refs	java_util_logging_Formatter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_logging_XMLFormatter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_logging_XMLFormatter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_logging_Formatter$sub_nonrefs	java_util_logging_Formatter;
    _jc_java_util_logging_XMLFormatter$sub_nonrefs	java_util_logging_XMLFormatter;
};

// Object instance structure
struct _jc_java_util_logging_XMLFormatter$object {
	_jc_java_util_logging_XMLFormatter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_logging_XMLFormatter$vtype	*vtype;
	_jc_java_util_logging_XMLFormatter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_logging_XMLFormatter$vtype _jc_java_util_logging_XMLFormatter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_logging_XMLFormatter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_logging_XMLFormatter$class_object;

#endif	/* _JC_java_util_logging_XMLFormatter_H_ */

==> jc-1.4.6.tar.gz: java/util/logging/XMLFormatter.h <==
// public class java.util.logging.XMLFormatter

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class afd6918748171c7a java_util_logging_Formatter
// @dep_class 762525b04b4e3b7f java_util_logging_XMLFormatter

// header file dependencies
// @dep_header java_util_logging_Formatter

#include "java/util/logging/Formatter.h"

#ifndef _JC_java_util_logging_XMLFormatter_H_
#define _JC_java_util_logging_XMLFormatter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_StringBuffer$object;
struct _jc_java_text_SimpleDateFormat$object;
struct _jc_java_util_logging_Handler$object;
struct _jc_java_util_logging_LogRecord$object;

// Typedefs
typedef struct _jc_java_util_logging_XMLFormatter$sub_refs	_jc_java_util_logging_XMLFormatter$sub_refs;
typedef struct _jc_java_util_logging_XMLFormatter$sub_nonrefs	_jc_java_util_logging_XMLFormatter$sub_nonrefs;
typedef struct _jc_java_util_logging_XMLFormatter$refs	_jc_java_util_logging_XMLFormatter$refs;
typedef struct _jc_java_util_logging_XMLFormatter$nonrefs	_jc_java_util_logging_XMLFormatter$nonrefs;
typedef struct _jc_java_util_logging_XMLFormatter$object	_jc_java_util_logging_XMLFormatter$object;

typedef struct _jc_java_util_logging_XMLFormatter$fields_struct	_jc_java_util_logging_XMLFormatter$fields_struct;
typedef const struct _jc_java_util_logging_XMLFormatter$vmethods	_jc_java_util_logging_XMLFormatter$vmethods;
typedef const struct _jc_java_util_logging_XMLFormatter$vtable	_jc_java_util_logging_XMLFormatter$vtable;
typedef const struct _jc_java_util_logging_XMLFormatter$vtype	_jc_java_util_logging_XMLFormatter$vtype;

// Class fields structure
struct _jc_java_util_logging_XMLFormatter$fields_struct {
	struct _jc_java_lang_String$object	*lineSep;
};
extern _jc_java_util_logging_XMLFormatter$fields_struct _jc_java_util_logging_XMLFormatter$class_fields;

// Constructors
extern void _jc_java_util_logging_XMLFormatter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_logging_XMLFormatter$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_util_logging_XMLFormatter$method$format$8b25c74979926e38(_jc_env *, struct _jc_java_util_logging_XMLFormatter$object *, struct _jc_java_util_logging_LogRecord$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_util_logging_XMLFormatter$method$getHead$98b66758a6126109(_jc_env *, struct _jc_java_util_logging_XMLFormatter$object *, struct _jc_java_util_logging_Handler$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_util_logging_XMLFormatter$method$getTail$ec946c1f995c0254(_jc_env *, struct _jc_java_util_logging_XMLFormatter$object *, struct _jc_java_util_logging_Handler$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_logging_XMLFormatter$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_util_logging_XMLFormatter$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_logging_XMLFormatter$method_info$format$8b25c74979926e38;
extern _jc_method _jc_java_util_logging_XMLFormatter$method_info$getHead$98b66758a6126109;
extern _jc_method _jc_java_util_logging_XMLFormatter$method_info$getTail$ec946c1f995c0254;
extern _jc_method _jc_java_util_logging_XMLFormatter$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern void _jc_java_util_logging_XMLFormatter$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_java_util_logging_XMLFormatter$method$appendTag$08c4a55cd695c006(_jc_env *, struct _jc_java_lang_StringBuffer$object *, jint, struct _jc_java_lang_String$object *, jlong) _JC_JCNI_ATTR;
extern void _jc_java_util_logging_XMLFormatter$method$appendTag$9e44c7a10e6953e8(_jc_env *, struct _jc_java_lang_StringBuffer$object *, jint, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_util_logging_XMLFormatter$vmethods {
	struct _jc_java_lang_String$object	*(*format$8b25c74979926e38)(_jc_env *, struct _jc_java_util_logging_XMLFormatter$object *, struct _jc_java_util_logging_LogRecord$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getHead$98b66758a6126109)(_jc_env *, struct _jc_java_util_logging_XMLFormatter$object *, struct _jc_java_util_logging_Handler$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getTail$ec946c1f995c0254)(_jc_env *, struct _jc_java_util_logging_XMLFormatter$object *, struct _jc_java_util_logging_Handler$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_util_logging_XMLFormatter$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_logging_XMLFormatter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_logging_Formatter$vmethods	java_util_logging_Formatter;
	_jc_java_util_logging_XMLFormatter$vmethods	java_util_logging_XMLFormatter;
};

// Vtype
struct _jc_java_util_logging_XMLFormatter$vtype {
	_jc_type			type;
	_jc_java_util_logging_XMLFormatter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_logging_XMLFormatter$sub_refs {
	struct _jc_java_text_SimpleDateFormat$object	*iso8601;
};

// Reference instance fields (object)
struct _jc_java_util_logging_XMLFormatter$refs {
    _jc_java_util_logging_XMLFormatter$sub_refs	java_util_logging_XMLFormatter;
    _jc_java_util_logging_Formatter$sub_refs	java_util_logging_Formatter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_logging_XMLFormatter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_logging_XMLFormatter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_logging_Formatter$sub_nonrefs	java_util_logging_Formatter;
    _jc_java_util_logging_XMLFormatter$sub_nonrefs	java_util_logging_XMLFormatter;
};

// Object instance structure
struct _jc_java_util_logging_XMLFormatter$object {
	_jc_java_util_logging_XMLFormatter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_logging_XMLFormatter$vtype	*vtype;
	_jc_java_util_logging_XMLFormatter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_logging_XMLFormatter$vtype _jc_java_util_logging_XMLFormatter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_logging_XMLFormatter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_logging_XMLFormatter$class_object;

#endif	/* _JC_java_util_logging_XMLFormatter_H_ */
